
/* the linux semctl prototype is broken as is the definition
   of union semun in sys/sem.h. */

#include <stddef.h>
#include "mytype.h"

#define entry_size (global.nsectors*cd_framesize)
